@@ -54,17 +54,22 @@ else
 fi
 iniset $TEMPEST_CONFIG share backend_names $BACKENDS_NAMES
 
-
-# Grab the supported API micro-versions from the code
-_API_VERSION_REQUEST_PATH=$BASE/new/manila/manila/api/openstack/api_version_request.py
-_DEFAULT_MIN_VERSION=$(awk '$0 ~ /_MIN_API_VERSION = /{print $3}' $_API_VERSION_REQUEST_PATH)
-_DEFAULT_MAX_VERSION=$(awk '$0 ~ /_MAX_API_VERSION = /{print $3}' $_API_VERSION_REQUEST_PATH)
-# Override the *_api_microversion tempest options if present
-MANILA_TEMPEST_MIN_API_MICROVERSION=${MANILA_TEMPEST_MIN_API_MICROVERSION:-$_DEFAULT_MIN_VERSION}
-MANILA_TEMPEST_MAX_API_MICROVERSION=${MANILA_TEMPEST_MAX_API_MICROVERSION:-$_DEFAULT_MAX_VERSION}
-# Set these options in tempest.conf
-iniset $TEMPEST_CONFIG share min_api_microversion $MANILA_TEMPEST_MIN_API_MICROVERSION
-iniset $TEMPEST_CONFIG share max_api_microversion $MANILA_TEMPEST_MAX_API_MICROVERSION
+# If testing a stable branch, we need to ensure we're testing with supported
+# API micro-versions; so set the versions from code if we're not testing the
+# master branch. If we're testing master, we'll allow manila-tempest-plugin
+# (which is branchless) tell us what versions it wants to test.
+if [[ $ZUUL_BRANCH != "master" ]]; then
+    # Grab the supported API micro-versions from the code
+    _API_VERSION_REQUEST_PATH=$BASE/new/manila/manila/api/openstack/api_version_request.py
+    _DEFAULT_MIN_VERSION=$(awk '$0 ~ /_MIN_API_VERSION = /{print $3}' $_API_VERSION_REQUEST_PATH)
+    _DEFAULT_MAX_VERSION=$(awk '$0 ~ /_MAX_API_VERSION = /{print $3}' $_API_VERSION_REQUEST_PATH)
+    # Override the *_api_microversion tempest options if present
+    MANILA_TEMPEST_MIN_API_MICROVERSION=${MANILA_TEMPEST_MIN_API_MICROVERSION:-$_DEFAULT_MIN_VERSION}
+    MANILA_TEMPEST_MAX_API_MICROVERSION=${MANILA_TEMPEST_MAX_API_MICROVERSION:-$_DEFAULT_MAX_VERSION}
+    # Set these options in tempest.conf
+    iniset $TEMPEST_CONFIG share min_api_microversion $MANILA_TEMPEST_MIN_API_MICROVERSION
+    iniset $TEMPEST_CONFIG share max_api_microversion $MANILA_TEMPEST_MAX_API_MICROVERSION
+fi
 
 # Set two retries for CI jobs
 iniset $TEMPEST_CONFIG share share_creation_retry_number 2
@@ -158,6 +163,12 @@ if [[ "$DRIVER" == "generic"* ]]; then
     RUN_MANILA_HOST_ASSISTED_MIGRATION_TESTS=True
     RUN_MANILA_MANAGE_SNAPSHOT_TESTS=True
     RUN_MANILA_CG_TESTS=False
+    if [[ "$MULTITENANCY_ENABLED" == "True"  ]]; then
+        # NOTE(ganso): The generic driver has not implemented support for
+        # Manage/unmanage shares/snapshots in DHSS=True
+        RUN_MANILA_MANAGE_SNAPSHOT_TESTS=False
+        RUN_MANILA_MANAGE_TESTS=False
+    fi
     if [[ "$POSTGRES_ENABLED" == "True" ]]; then
         # Run only CIFS tests on PostgreSQL DB backend
         # to reduce amount of tests per job using 'generic' share driver.
@@ -236,7 +247,8 @@ elif [[ "$DRIVER" == "dummy" ]]; then
     MANILA_TEMPEST_CONCURRENCY=24
     MANILA_CONFIGURE_DEFAULT_TYPES=False
     RUN_MANILA_SG_TESTS=True
-    RUN_MANILA_MANAGE_TESTS=False
+    RUN_MANILA_MANAGE_TESTS=True
+    RUN_MANILA_MANAGE_SNAPSHOT_TESTS=True
     RUN_MANILA_DRIVER_ASSISTED_MIGRATION_TESTS=True
     RUN_MANILA_REVERT_TO_SNAPSHOT_TESTS=True
     RUN_MANILA_MOUNT_SNAPSHOT_TESTS=True
@@ -255,7 +267,6 @@ elif [[ "$DRIVER" == "dummy" ]]; then
     iniset $TEMPEST_CONFIG share create_networks_when_multitenancy_enabled False
     iniset $TEMPEST_CONFIG share multi_backend True
 elif [[ "$DRIVER" == "container"* ]]; then
-    MANILA_TESTS="(^manila_tempest_tests.tests.api)(?=.*\[.*\bbackend\b.*\])"
     if [[ "$DRIVER" == "container_with_custom_image" ]]; then
         # TODO(vponomaryov): set scenario tests for run when
         # manila tempest plugin supports share protocol and rules that
@@ -265,7 +276,7 @@ elif [[ "$DRIVER" == "container"* ]]; then
     fi
     MANILA_TEMPEST_CONCURRENCY=8
     RUN_MANILA_SG_TESTS=False
-    RUN_MANILA_MANAGE_TESTS=False
+    RUN_MANILA_MANAGE_TESTS=True
     RUN_MANILA_QUOTA_TESTS=False
     RUN_MANILA_SHRINK_TESTS=False
     RUN_MANILA_SNAPSHOT_TESTS=False
@@ -322,9 +333,6 @@ if [ $(trueorfalse False MANILA_CONFIGURE_DEFAULT_TYPES) == True ]; then
     iniset $TEMPEST_CONFIG share default_share_type_name ${MANILA_DEFAULT_SHARE_TYPE:-default}
 fi
 
-# check if tempest plugin was installed correctly
-echo 'import pkg_resources; print list(pkg_resources.iter_entry_points("tempest.test_plugins"))' | python
-
 ADMIN_DOMAIN_NAME=${ADMIN_DOMAIN_NAME:-"Default"}
 export OS_PROJECT_DOMAIN_NAME=$ADMIN_DOMAIN_NAME
 export OS_USER_DOMAIN_NAME=$ADMIN_DOMAIN_NAME
@@ -353,11 +361,12 @@ source $BASE/new/devstack/openrc admin admin
 public_net_id=$(openstack network list --name $PUBLIC_NETWORK_NAME -f value -c ID )
 iniset $TEMPEST_CONFIG network public_network_id $public_net_id
 
-# Now that all plugins are loaded, setup BGP here
 if [ $(trueorfalse False MANILA_SETUP_IPV6) == True ]; then
+    # Now that all plugins are loaded, setup BGP here
+    public_gateway_ipv6=$(openstack subnet show ipv6-public-subnet -c gateway_ip -f value)
     neutron bgp-speaker-create --ip-version 6 --local-as 100 bgpspeaker
     neutron bgp-speaker-network-add bgpspeaker $PUBLIC_NETWORK_NAME
-    neutron bgp-peer-create --peer-ip ::1 --remote-as 200 bgppeer
+    neutron bgp-peer-create --peer-ip $public_gateway_ipv6 --remote-as 200 bgppeer
     neutron bgp-speaker-peer-add bgpspeaker bgppeer
 fi
 
@@ -371,8 +380,14 @@ if ! [[ -z "$OVERRIDE_IP_FOR_NFS_ACCESS" ]]; then
     iniset $TEMPEST_CONFIG share override_ip_for_nfs_access $OVERRIDE_IP_FOR_NFS_ACCESS
 fi
 
+echo "Manila service details"
+source $BASE/new/devstack/openrc admin admin
+manila service-list
+
 echo "Running tempest manila test suites"
 cd $BASE/new/tempest/
+# List plugins in logs to enable debugging
+sudo -H -u $USER tempest list-plugins
 sudo -H -u $USER tempest run -r $MANILA_TESTS --concurrency=$MANILA_TEMPEST_CONCURRENCY
 RETVAL=$?
 cd -
