@@ -59,6 +59,10 @@ function cleanup_manila {
     _clean_share_group $SHARE_GROUP $SHARE_NAME_PREFIX
     _clean_manila_lvm_backing_file $SHARE_GROUP
     _clean_zfsonlinux_data
+
+    if [ $(trueorfalse False MANILA_USE_UWSGI) == True ]; then
+        remove_uwsgi_config "$MANILA_UWSGI_CONF" "$MANILA_WSGI"
+    fi
 }
 
 # _config_manila_apache_wsgi() - Configure manila-api wsgi application.
@@ -144,6 +148,23 @@ function set_cinder_quotas {
     fi
 }
 
+function set_backend_availability_zones {
+    ENABLED_BACKENDS=$1
+    echo_summary "Setting up backend_availability_zone option \
+        for any enabled backends that do not use the Generic driver. \
+        Availability zones for the Generic driver must coincide with those \
+        created for Nova and Cinder."
+    local zonenum
+    generic_driver='manila.share.drivers.generic.GenericShareDriver'
+    for BE in ${ENABLED_BACKENDS//,/ }; do
+        share_driver=$(iniget $MANILA_CONF $BE share_driver)
+        if [[ $share_driver != $generic_driver ]]; then
+            zone="manila-zone-$((zonenum++))"
+            iniset $MANILA_CONF $BE backend_availability_zone $zone
+        fi
+    done
+}
+
 # configure_manila - Set config files, create data dirs, etc
 function configure_manila {
     if [[ ! -d $MANILA_CONF_DIR ]]; then
@@ -204,8 +225,13 @@ function configure_manila {
     iniset $MANILA_CONF DEFAULT rootwrap_config $MANILA_CONF_DIR/rootwrap.conf
     iniset $MANILA_CONF DEFAULT osapi_share_extension manila.api.contrib.standard_extensions
     iniset $MANILA_CONF DEFAULT state_path $MANILA_STATE_PATH
-    iniset $MANILA_CONF DEFAULT default_share_type $MANILA_DEFAULT_SHARE_TYPE
-    iniset $MANILA_CONF DEFAULT default_share_group_type $MANILA_DEFAULT_SHARE_GROUP_TYPE
+
+    # Note: Sample share types will still be created if the below is False
+
+    if [ $(trueorfalse False MANILA_CONFIGURE_DEFAULT_TYPES) == True ]; then
+        iniset $MANILA_CONF DEFAULT default_share_type $MANILA_DEFAULT_SHARE_TYPE
+        iniset $MANILA_CONF DEFAULT default_share_group_type $MANILA_DEFAULT_SHARE_GROUP_TYPE
+    fi
 
     if ! [[ -z $MANILA_SHARE_MIGRATION_PERIOD_TASK_INTERVAL ]]; then
         iniset $MANILA_CONF DEFAULT migration_driver_continue_update_interval $MANILA_SHARE_MIGRATION_PERIOD_TASK_INTERVAL
@@ -257,8 +283,9 @@ function configure_manila {
 
     REAL_MANILA_SERVICE_PORT=$MANILA_SERVICE_PORT
     if is_service_enabled tls-proxy; then
-        # Set the protocol to 'https', and set the default port
+        # Set the protocol to 'https', update the endpoint base and set the default port
         MANILA_SERVICE_PROTOCOL="https"
+        MANILA_ENDPOINT_BASE="${MANILA_ENDPOINT_BASE/http:/https:}"
         REAL_MANILA_SERVICE_PORT=$MANILA_SERVICE_PORT_INT
         # Set the service port for a proxy to take the original
         iniset $MANILA_CONF DEFAULT osapi_share_listen_port $REAL_MANILA_SERVICE_PORT
@@ -272,6 +299,11 @@ function configure_manila {
     MANILA_CONFIGURE_GROUPS=${MANILA_CONFIGURE_GROUPS:-"$MANILA_ENABLED_BACKENDS"}
     set_config_opts $MANILA_CONFIGURE_GROUPS
     set_config_opts DEFAULT
+    set_backend_availability_zones $MANILA_ENABLED_BACKENDS
+
+    if [ $(trueorfalse False MANILA_USE_UWSGI) == True ]; then
+        write_uwsgi_config "$MANILA_UWSGI_CONF" "$MANILA_WSGI" "/share"
+    fi
 
     if [ $(trueorfalse False MANILA_USE_MOD_WSGI) == True ]; then
         _config_manila_apache_wsgi
@@ -460,19 +492,14 @@ function create_manila_accounts {
 
     create_service_user "manila"
 
-    # Set up Manila v1 service and endpoint
     get_or_create_service "manila" "share" "Manila Shared Filesystem Service"
     get_or_create_endpoint "share" "$REGION_NAME" \
-        "$MANILA_SERVICE_PROTOCOL://$MANILA_SERVICE_HOST:$MANILA_SERVICE_PORT/v1/\$(tenant_id)s" \
-        "$MANILA_SERVICE_PROTOCOL://$MANILA_SERVICE_HOST:$MANILA_SERVICE_PORT/v1/\$(tenant_id)s" \
-        "$MANILA_SERVICE_PROTOCOL://$MANILA_SERVICE_HOST:$MANILA_SERVICE_PORT/v1/\$(tenant_id)s"
+        "$MANILA_ENDPOINT_BASE/v1/\$(project_id)s"
 
     # Set up Manila v2 service and endpoint
     get_or_create_service "manilav2" "sharev2" "Manila Shared Filesystem Service V2"
     get_or_create_endpoint "sharev2" "$REGION_NAME" \
-        "$MANILA_SERVICE_PROTOCOL://$MANILA_SERVICE_HOST:$MANILA_SERVICE_PORT/v2/\$(tenant_id)s" \
-        "$MANILA_SERVICE_PROTOCOL://$MANILA_SERVICE_HOST:$MANILA_SERVICE_PORT/v2/\$(tenant_id)s" \
-        "$MANILA_SERVICE_PROTOCOL://$MANILA_SERVICE_HOST:$MANILA_SERVICE_PORT/v2/\$(tenant_id)s"
+        "$MANILA_ENDPOINT_BASE/v2/\$(project_id)s"
 }
 
 # create_default_share_group_type - create share group type that will be set as default.
@@ -486,7 +513,10 @@ function create_default_share_group_type {
     fi
 }
 
-# create_default_share_type - create share type that will be set as default.
+# create_default_share_type - create share type that will be set as default
+# if $MANILA_CONFIGURE_DEFAULT_TYPES is set to True, if set to False, the share
+# type identified by $MANILA_DEFAULT_SHARE_TYPE is still created, but not
+# configured as default.
 function create_default_share_type {
     enabled_backends=(${MANILA_ENABLED_BACKENDS//,/ })
     driver_handles_share_servers=$(iniget $MANILA_CONF ${enabled_backends[0]} driver_handles_share_servers)
@@ -522,6 +552,7 @@ function create_custom_share_types {
 
 # configure_backing_file - Set up backing file for LVM
 function configure_backing_file {
+    sudo vgscan
     if ! sudo vgs $SHARE_GROUP; then
         if [ "$CONFIGURE_BACKING_FILE" = "True" ]; then
             SHARE_BACKING_FILE=${SHARE_BACKING_FILE:-$DATA_DIR/${SHARE_GROUP}-backing-file}
@@ -714,11 +745,12 @@ function install_manila {
                         sudo apt-get install -y linux-headers-generic
                         sudo apt-get install -y build-essential
                         sudo apt-get install -y ubuntu-zfs
-                    elif [[ $(lsb_release -s -d) == *"16.04"* ]]; then
-                        # Xenial
+
+                    elif [[ $(echo $(lsb_release -rs) '>=' 16.04 | bc -l) == 1 ]]; then
+                        # Xenial and beyond
                         sudo apt-get install -y zfsutils-linux
                     else
-                        echo "Only 'Trusty' and 'Xenial' releases of Ubuntu are supported."
+                        echo "Only 'Trusty', 'Xenial' and newer releases of Ubuntu are supported."
                         exit 1
                     fi
                 else
@@ -789,28 +821,56 @@ function configure_samba {
 
 # start_manila_api - starts manila API services and checks its availability
 function start_manila_api {
-    if [ $(trueorfalse False MANILA_USE_MOD_WSGI) == True ]; then
+
+    # NOTE(vkmc) If both options are set to true we are using uwsgi
+    # as the preferred way to deploy manila. See
+    # https://governance.openstack.org/tc/goals/pike/deploy-api-in-wsgi.html#uwsgi-vs-mod-wsgi
+    # for more details
+    if [ $(trueorfalse False MANILA_USE_UWSGI) == True ] && [ $(trueorfalse False MANILA_USE_MOD_WSGI) == True ]; then
+        MSG="Both MANILA_USE_UWSGI and MANILA_USE_MOD_WSGI are set to True.
+            Using UWSGI as the preferred option
+            Set MANILA_USE_UWSGI to False to deploy manila api with MOD_WSGI"
+        warn $LINENO $MSG
+    fi
+
+    if [ $(trueorfalse False MANILA_USE_UWSGI) == True ]; then
+        echo "Deploying with UWSGI"
+        run_process m-api "$MANILA_BIN_DIR/uwsgi --ini $MANILA_UWSGI_CONF --procname-prefix manila-api"
+    elif [ $(trueorfalse False MANILA_USE_MOD_WSGI) == True ]; then
+        echo "Deploying with MOD_WSGI"
         install_apache_wsgi
         enable_apache_site manila-api
         restart_apache_server
         tail_log m-api /var/log/$APACHE_NAME/manila_api.log
     else
+        echo "Deploying with built-in server"
         run_process m-api "$MANILA_BIN_DIR/manila-api --config-file $MANILA_CONF"
     fi
 
-
     echo "Waiting for Manila API to start..."
     # This is a health check against the manila-api service we just started.
     # We use the port ($REAL_MANILA_SERVICE_PORT) here because we want to hit
     # the bare service endpoint, even if the tls tunnel should be enabled.
     # We're making sure that the internal port is checked using unencryted
     # traffic at this point.
-    if ! wait_for_service $SERVICE_TIMEOUT $MANILA_SERVICE_PROTOCOL://$MANILA_SERVICE_HOST:$REAL_MANILA_SERVICE_PORT; then
+
+    local MANILA_HEALTH_CHECK_URL=$MANILA_SERVICE_PROTOCOL://$MANILA_SERVICE_HOST:$REAL_MANILA_SERVICE_PORT
+
+    if [ $(trueorfalse False MANILA_USE_UWSGI) == True ]; then
+        MANILA_HEALTH_CHECK_URL=$MANILA_ENDPOINT_BASE
+    fi
+
+    if ! wait_for_service $SERVICE_TIMEOUT $MANILA_HEALTH_CHECK_URL; then
         die $LINENO "Manila API did not start"
     fi
 
     # Start proxies if enabled
-    if is_service_enabled tls-proxy; then
+    #
+    # If tls-proxy is enabled and MANILA_USE_UWSGI is set to True, a generic
+    # http-services-tls-proxy will be set up to handle tls-termination to
+    # manila as well as all the other https services, we don't need to
+    # create our own.
+    if [ $(trueorfalse False MANILA_USE_UWSGI) == False ] && is_service_enabled tls-proxy; then
         start_tls_proxy manila '*' $MANILA_SERVICE_PORT $MANILA_SERVICE_HOST $MANILA_SERVICE_PORT_INT
     fi
 }
@@ -965,8 +1025,8 @@ function setup_ipv6 {
     sudo ovs-vsctl set Bridge $PUBLIC_BRIDGE other_config:disable-in-band=true
 
     # Create address scopes and subnet pools
-    neutron address-scope-create --shared scope-v4 4
-    neutron address-scope-create --shared scope-v6 6
+    openstack address scope create --share --ip-version 4 scope-v4
+    openstack address scope create --share --ip-version 6 scope-v6
     openstack subnet pool create $SUBNETPOOL_NAME_V4 --default-prefix-length $SUBNETPOOL_SIZE_V4 --pool-prefix $SUBNETPOOL_PREFIX_V4 --address-scope scope-v4 --default --share
     openstack subnet pool create $SUBNETPOOL_NAME_V6 --default-prefix-length $SUBNETPOOL_SIZE_V6 --pool-prefix $SUBNETPOOL_PREFIX_V6 --address-scope scope-v6 --default --share
 
@@ -1023,16 +1083,22 @@ function setup_ipv6 {
     echo "log file /var/log/quagga/zebra.log"
     ) | sudo tee /etc/quagga/zebra.conf > /dev/null
 
+    # set Quagga vtysh.conf
+    (
+    echo "service integrated-vtysh-config"
+    echo "username quagga nopassword"
+    ) | sudo tee /etc/quagga/vtysh.conf > /dev/null
+
     # set Quagga bgpd.conf
     (
     echo "log file /var/log/quagga/bgpd.log"
     echo "bgp multiple-instance"
     echo "router bgp 200"
     echo " bgp router-id 1.2.3.4"
-    echo " neighbor ::1 remote-as 100"
-    echo " neighbor ::1 passive"
+    echo " neighbor $public_gateway_ipv6 remote-as 100"
+    echo " neighbor $public_gateway_ipv6 passive"
     echo " address-family ipv6"
-    echo "  neighbor ::1 activate"
+    echo "  neighbor $public_gateway_ipv6 activate"
     echo "line vty"
     echo "debug bgp events"
     echo "debug bgp filters"
@@ -1041,21 +1107,34 @@ function setup_ipv6 {
     echo "debug bgp updates"
     ) | sudo tee /etc/quagga/bgpd.conf > /dev/null
 
-    if is_ubuntu; then
-        sudo systemctl enable quagga
-        sudo systemctl restart quagga
-    else
+    # Quagga logging
+    sudo mkdir -p /var/log/quagga
+    sudo touch /var/log/quagga/zebra.log
+    sudo touch /var/log/quagga/bgpd.log
+    sudo chown -R quagga:quagga /var/log/quagga
+
+
+    GetOSVersion
+    QUAGGA_SERVICES="zebra bgpd"
+    if [[ is_ubuntu && "$os_CODENAME" == "xenial" ]]; then
+        # In Ubuntu Xenial, the services bgpd and zebra are under
+        # one systemd unit: quagga
+        QUAGGA_SERVICES="quagga"
+    elif is_fedora; then
         # Disable SELinux rule that conflicts with Zebra
         sudo setsebool -P zebra_write_config 1
-        sudo systemctl enable zebra
-        sudo systemctl enable bgpd
-        sudo systemctl restart zebra
-        sudo systemctl restart bgpd
     fi
+    sudo systemctl enable $QUAGGA_SERVICES
+    sudo systemctl restart $QUAGGA_SERVICES
+
+    # log the systemd status
+    sudo systemctl status $QUAGGA_SERVICES
 
     # add default IPv6 route back
     if ! [[ -z $default_route ]]; then
-        sudo ip -6 route add $default_route
+        # "replace" should ignore "RTNETLINK answers: File exists"
+        # error if the route wasn't flushed by the bgp setup we did earlier.
+        sudo ip -6 route replace $default_route
     fi
 
 }
@@ -1137,7 +1216,7 @@ elif [[ "$1" == "stack" && "$2" == "extra" ]]; then
     create_custom_share_types
 
     echo_summary "Manila UI is no longer enabled by default. \
-        Add enable_plugin manila-ui github.com/openstack/manila-ui \
+        Add enable_plugin manila-ui https://git.openstack.org/openstack/manila-ui \
         to your local.conf file to enable Manila UI"
 
 elif [[ "$1" == "stack" && "$2" == "test-config" ]]; then
