@@ -27,7 +27,6 @@ from manila.api.v1 import scheduler_stats
 from manila.api.v1 import security_service
 from manila.api.v1 import share_manage
 from manila.api.v1 import share_metadata
-from manila.api.v1 import share_servers
 from manila.api.v1 import share_types_extra_specs
 from manila.api.v1 import share_unmanage
 from manila.api.v2 import availability_zones
@@ -45,7 +44,9 @@ from manila.api.v2 import share_groups
 from manila.api.v2 import share_instance_export_locations
 from manila.api.v2 import share_instances
 from manila.api.v2 import share_networks
+from manila.api.v2 import share_replica_export_locations
 from manila.api.v2 import share_replicas
+from manila.api.v2 import share_servers
 from manila.api.v2 import share_snapshot_export_locations
 from manila.api.v2 import share_snapshot_instance_export_locations
 from manila.api.v2 import share_snapshot_instances
@@ -298,12 +299,18 @@ class APIRouter(manila.api.openstack.APIRouter):
         self.resources["share_servers"] = share_servers.create_resource()
         mapper.resource("share_server",
                         "share-servers",
-                        controller=self.resources["share_servers"])
+                        controller=self.resources["share_servers"],
+                        member={"action": "POST"})
         mapper.connect("details",
                        "/{project_id}/share-servers/{id}/details",
                        controller=self.resources["share_servers"],
                        action="details",
                        conditions={"method": ["GET"]})
+        mapper.connect("share_servers",
+                       "/{project_id}/share-servers/manage",
+                       controller=self.resources["share_servers"],
+                       action="manage",
+                       conditions={"method": ["POST"]})
 
         self.resources["types"] = share_types.create_resource()
         mapper.resource("type", "types",
@@ -413,6 +420,22 @@ class APIRouter(manila.api.openstack.APIRouter):
                         controller=self.resources['share-replicas'],
                         collection={'detail': 'GET'},
                         member={'action': 'POST'})
+        self.resources["share-replica-export-locations"] = (
+            share_replica_export_locations.create_resource())
+        mapper.connect("share-replicas",
+                       ("/{project_id}/share-replicas/{share_replica_id}/"
+                        "export-locations"),
+                       controller=self.resources[
+                           "share-replica-export-locations"],
+                       action="index",
+                       conditions={"method": ["GET"]})
+        mapper.connect("share-replicas",
+                       ("/{project_id}/share-replicas/{share_replica_id}/"
+                        "export-locations/{export_location_uuid}"),
+                       controller=self.resources[
+                           "share-replica-export-locations"],
+                       action="show",
+                       conditions={"method": ["GET"]})
 
         self.resources['messages'] = messages.create_resource()
         mapper.resource("message", "messages",
