@@ -324,6 +324,11 @@ def share_instance_update(context, instance_id, values, with_share_data=False):
                                       with_share_data=with_share_data)
 
 
+def share_instances_host_update(context, current_host, new_host):
+    """Update the host attr of all share instances that are on current_host."""
+    return IMPL.share_instances_host_update(context, current_host, new_host)
+
+
 def share_instances_get_all(context, filters=None):
     """Returns all share instances."""
     return IMPL.share_instances_get_all(context, filters=filters)
@@ -722,10 +727,12 @@ def share_metadata_update(context, share, metadata, delete):
 
 ###################
 
-def share_export_location_get_by_uuid(context, export_location_uuid):
+def share_export_location_get_by_uuid(context, export_location_uuid,
+                                      ignore_secondary_replicas=False):
     """Get specific export location of a share."""
     return IMPL.share_export_location_get_by_uuid(
-        context, export_location_uuid)
+        context, export_location_uuid,
+        ignore_secondary_replicas=ignore_secondary_replicas)
 
 
 def share_export_locations_get(context, share_id):
@@ -735,18 +742,21 @@ def share_export_locations_get(context, share_id):
 
 def share_export_locations_get_by_share_id(context, share_id,
                                            include_admin_only=True,
-                                           ignore_migration_destination=False):
+                                           ignore_migration_destination=False,
+                                           ignore_secondary_replicas=False):
     """Get all export locations of a share by its ID."""
     return IMPL.share_export_locations_get_by_share_id(
         context, share_id, include_admin_only=include_admin_only,
-        ignore_migration_destination=ignore_migration_destination)
+        ignore_migration_destination=ignore_migration_destination,
+        ignore_secondary_replicas=ignore_secondary_replicas)
 
 
 def share_export_locations_get_by_share_instance_id(context,
-                                                    share_instance_id):
+                                                    share_instance_id,
+                                                    include_admin_only=True):
     """Get all export locations of a share instance by its ID."""
     return IMPL.share_export_locations_get_by_share_instance_id(
-        context, share_instance_id)
+        context, share_instance_id, include_admin_only=include_admin_only)
 
 
 def share_export_locations_update(context, share_instance_id, export_locations,
@@ -848,9 +858,16 @@ def network_allocation_delete(context, id):
     return IMPL.network_allocation_delete(context, id)
 
 
-def network_allocation_update(context, id, values):
+def network_allocation_update(context, id, values, read_deleted=None):
     """Update a network allocation DB record."""
-    return IMPL.network_allocation_update(context, id, values)
+    return IMPL.network_allocation_update(context, id, values,
+                                          read_deleted=read_deleted)
+
+
+def network_allocation_get(context, id, session=None, read_deleted=None):
+    """Get a network allocation DB record."""
+    return IMPL.network_allocation_get(context, id, session,
+                                       read_deleted=read_deleted)
 
 
 def network_allocations_get_for_share_server(context, share_server_id,
@@ -888,6 +905,12 @@ def share_server_get(context, id, session=None):
     return IMPL.share_server_get(context, id, session=session)
 
 
+def share_server_search_by_identifier(context, identifier, session=None):
+    """Search for share servers based on given identifier."""
+    return IMPL.share_server_search_by_identifier(
+        context, identifier, session=session)
+
+
 def share_server_get_all_by_host_and_share_net_valid(context, host,
                                                      share_net_id,
                                                      session=None):
